about summary refs log tree commit diff
path: root/shared/nm-utils/c-list.h
diff options
context:
space:
mode:
authorMichael Biebl <biebl@debian.org>2017-12-12 15:53:07 +0100
committerMichael Biebl <biebl@debian.org>2017-12-12 15:53:07 +0100
commitafcd268ea7b1149fbfb66bce4eca659b675da0a2 (patch)
treec3fca2203ad17434daf3ccf576582bd66aa41ab2 /shared/nm-utils/c-list.h
parent417f6015c3dc8c47cf27daa59f64e0e36c521b9c (diff)
New upstream version 1.10.2 upstream/1.10.2
Diffstat (limited to 'shared/nm-utils/c-list.h')
-rw-r--r--shared/nm-utils/c-list.h14
1 files changed, 7 insertions, 7 deletions
diff --git a/shared/nm-utils/c-list.h b/shared/nm-utils/c-list.h
index 557862b6..a3c4053b 100644
--- a/shared/nm-utils/c-list.h
+++ b/shared/nm-utils/c-list.h
@@ -142,7 +142,7 @@ static inline void c_list_link_after(CList *where, CList *what) {
 #define c_list_link_front(_list, _what) c_list_link_after((_list), (_what))
 
 /**
  * c_list_unlink() - unlink element from list
  * @what:               element to unlink
  *
  * This unlinks @what. If @what was initialized via C_LIST_INIT(), it has no
@@ -150,9 +150,9 @@ static inline void c_list_link_after(CList *where, CList *what) {
  *
  * Note that this does not modify @what. It just modifies the previous and next
  * elements in the list to no longer reference @what. If you want to make sure
- * @what is re-initialized after removal, use c_list_unlink_init().
+ * @what is re-initialized after removal, use c_list_unlink().
  */
-static inline void c_list_unlink(CList *what) {
+static inline void c_list_unlink_stale(CList *what) {
         CList *prev = what->prev, *next = what->next;
 
         next->prev = prev;
@@ -160,15 +160,15 @@ static inline void c_list_unlink(CList *what) {
 }
 
 /**
- * c_list_unlink_init() - unlink element from list and re-initialize
+ * c_list_unlink() - unlink element from list and re-initialize
  * @what:               element to unlink
  *
  * This is like c_list_unlink() but re-initializes @what after removal.
  */
-static inline void c_list_unlink_init(CList *what) {
+static inline void c_list_unlink(CList *what) {
         /* condition is not needed, but avoids STOREs in fast-path */
         if (c_list_is_linked(what)) {
-                c_list_unlink(what);
+                c_list_unlink_stale(what);
                 *what = (CList)C_LIST_INIT(*what);
         }
 }
@@ -142,7 +142,7 @@ static inline void c_list_link_after(CList *where, CList *what) {
 
 /**
- * c_list_unlink() - unlink element from list
+ * c_list_unlink_stale() - unlink element from list
  * @what:               element to unlink
  *
@@ -160,15 +160,15 @@ static inline void c_list_unlink(CList *what) {
  * @what:               element to unlink
  *
- * This is like c_list_unlink() but re-initializes @what after removal.
+ * This is like c_list_unlink_stale() but re-initializes @what after removal.
  */